NAME
SBOM::CycloneDX::Enum::AggregateType - Specifies an aggregate type that describes how complete a relationship is
SYNOPSIS
use SBOM::CycloneDX::Enum qw(AGGREGATE_TYPE);
say AGGREGATE_TYPE->NOT_SPECIFIED;
use SBOM::CycloneDX::Enum::AggregateType;
say SBOM::CycloneDX::Enum::AggregateType->COMPLETE;
use SBOM::CycloneDX::Enum::AggregateType qw(:all);
say INCOMPLETE;
DESCRIPTION
SBOM::CycloneDX::Enum::AggregateType is ENUM package used by SBOM::CycloneDX::Composition.
CONSTANTS
COMPLETE, The relationship is complete. No further relationships including constituent components, services, or dependencies are known to exist.INCOMPLETE, The relationship is incomplete. Additional relationships exist and may include constituent components, services, or dependencies.INCOMPLETE_FIRST_PARTY_ONLY, The relationship is incomplete. Only relationships for first-party components, services, or their dependencies are represented.INCOMPLETE_FIRST_PARTY_PROPRIETARY_ONLY, The relationship is incomplete. Only relationships for first-party components, services, or their dependencies are represented, limited specifically to those that are proprietary.INCOMPLETE_FIRST_PARTY_OPENSOURCE_ONLY, The relationship is incomplete. Only relationships for first-party components, services, or their dependencies are represented, limited specifically to those that are opensource.INCOMPLETE_THIRD_PARTY_ONLY, The relationship is incomplete. Only relationships for third-party components, services, or their dependencies are represented.INCOMPLETE_THIRD_PARTY_PROPRIETARY_ONLY, The relationship is incomplete. Only relationships for third-party components, services, or their dependencies are represented, limited specifically to those that are proprietary.INCOMPLETE_THIRD_PARTY_OPENSOURCE_ONLY, The relationship is incomplete. Only relationships for third-party components, services, or their dependencies are represented, limited specifically to those that are opensource.UNKNOWN, The relationship may be complete or incomplete. This usually signifies a 'best-effort' to obtain constituent components, services, or dependencies but the completeness is inconclusive.NOT_SPECIFIED, The relationship completeness is not specified.
SUPPORT
Bugs / Feature Requests
Please report any bugs or feature requests through the issue tracker at https://github.com/giterlizzi/perl-SBOM-CycloneDX/issues. You will be notified automatically of any progress on your issue.
Source Code
This is open source software. The code repository is available for public review and contribution under the terms of the license.
https://github.com/giterlizzi/perl-SBOM-CycloneDX
git clone https://github.com/giterlizzi/perl-SBOM-CycloneDX.git
AUTHOR
Giuseppe Di Terlizzi <gdt@cpan.org>
LICENSE AND COPYRIGHT
This software is copyright (c) 2025-2026 by Giuseppe Di Terlizzi.
This is free software; you can redistribute it and/or modify it under the same terms as the Perl 5 programming language system itself.